<?php
function uwp_get_listings_count($post_type, $user_id = 0)
{
    global $wpdb;
    if (empty($user_id)) {
        return 0;
    }

    $post_status = is_super_admin() ? " OR " . $wpdb->posts . ".post_status = 'private'" : '';
    if ($user_id && $user_id == get_current_user_id()) {
        $post_status .= " OR " . $wpdb->posts . ".post_status = 'draft' OR " . $wpdb->posts . ".post_status = 'private'";
    }

    $count = (int)$wpdb->get_var("SELECT count( ID ) FROM " . $wpdb->prefix . "posts WHERE post_author=" . (int)$user_id . " AND post_type='" . $post_type . "' AND ( post_status = 'publish' " . $post_status . " )");

    return apply_filters('geodir_uwp_count_total', $count, $user_id);
}

function uwp_get_total_listings_count($user_id = 0)
{

    if (empty($user_id)) {
        return 0;
    }

    $gd_post_types = geodir_get_posttypes('array');

    if (empty($gd_post_types)) {
        return 0;
    }


    // allowed post types
    $listing_post_types = uwp_get_option('gd_profile_listings', array());

    if (!is_array($listing_post_types)) {
        $listing_post_types = array();
    }

    $count = 0;
    $total_count = 0;
    foreach ($listing_post_types as $post_type) {
        if (array_key_exists($post_type, $gd_post_types)) {

            // get listing count
            $listing_count = uwp_get_listings_count($post_type, $user_id);
            $total_count += $listing_count;

            $count++;
        }
    }

    return $total_count;
}

function uwp_get_total_reviews_count($user_id = 0)
{

    if (empty($user_id)) {
        return 0;
    }

    $gd_post_types = geodir_get_posttypes('array');

    if (empty($gd_post_types)) {
        return 0;
    }

    // allowed post types
    $listing_post_types = uwp_get_option('gd_profile_reviews', array());

    if (!is_array($listing_post_types)) {
        $listing_post_types = array();
    }

    $count = 0;
    $total_count = 0;
    foreach ($listing_post_types as $post_type) {
        if (array_key_exists($post_type, $gd_post_types)) {

            // get listing count
            $listing_count = uwp_geodir_get_reviews_by_user_id($post_type, $user_id, true);
            $total_count += $listing_count;

            $count++;
        }
    }

    return $total_count;
}

function uwp_get_total_favorites_count($user_id = 0)
{

    if (empty($user_id)) {
        return 0;
    }

    $gd_post_types = geodir_get_posttypes('array');

    if (empty($gd_post_types)) {
        return 0;
    }

    // allowed post types
    $listing_post_types = uwp_get_option('gd_profile_favorites', array());

    if (!is_array($listing_post_types)) {
        $listing_post_types = array();
    }

    $count = 0;
    $total_count = 0;
    foreach ($listing_post_types as $post_type) {
        if (array_key_exists($post_type, $gd_post_types)) {

            // get listing count
            $listing_count = uwp_geodir_count_favorite($post_type, $user_id);
            $total_count += $listing_count;

            $count++;
        }
    }

    return $total_count;
}

add_filter('uwp_profile_tabs', 'uwp_add_profile_gd_tabs', 10, 2);
function uwp_add_profile_gd_tabs($tabs, $user)
{

    //disable?
    $disable = uwp_get_option('disable_uwp_gd', "0");

    if ($disable == "1") {
        return $tabs;
    }


    // allowed post types
    $listing_post_types = uwp_get_option('gd_profile_listings', array());
    if (!empty($listing_post_types)) {
        $tabs['listings'] = array(
            'title' => __('Listings', 'uwp-gd'),
            'count' => uwp_get_total_listings_count($user->ID)
        );
    }

    $listing_post_types = uwp_get_option('gd_profile_reviews', array());
    if (!empty($listing_post_types)) {
        $tabs['reviews'] = array(
            'title' => __('Reviews', 'uwp-gd'),
            'count' => uwp_get_total_reviews_count($user->ID)
        );
    }

    $listing_post_types = uwp_get_option('gd_profile_favorites', array());
    if (!empty($listing_post_types)) {
        $tabs['favorites'] = array(
            'title' => __('Favorites', 'uwp-gd'),
            'count' => uwp_get_total_favorites_count($user->ID)
        );
    }

    if (class_exists('WPInv_Invoice')) {
        $tabs['invoices'] = array(
            'title' => __('Invoices', 'uwp-gd'),
            'count' => uwp_post_count($user->ID, 'wpi_invoice')
        );
    }

    return $tabs;
}

add_action('uwp_profile_listings_tab_content', 'uwp_add_profile_listings_tab_content');
function uwp_add_profile_listings_tab_content($user)
{
    uwp_profile_gd_subtabs_content($user, 'listings');
}

add_action('uwp_profile_reviews_tab_content', 'uwp_add_profile_reviews_tab_content');
function uwp_add_profile_reviews_tab_content($user)
{
    uwp_profile_gd_subtabs_content($user, 'reviews');
}

add_action('uwp_profile_favorites_tab_content', 'uwp_add_profile_favorites_tab_content');
function uwp_add_profile_favorites_tab_content($user)
{
    uwp_profile_gd_subtabs_content($user, 'favorites');
}

add_action('uwp_profile_invoices_tab_content', 'uwp_add_profile_invoices_tab_content');
function uwp_add_profile_invoices_tab_content($user)
{
    uwp_profile_gd_invoices_content($user);
}

function uwp_profile_gd_subtabs($user, $type = 'listings')
{

    $tabs = array();

    $gd_post_types = geodir_get_posttypes('array');

    if (empty($gd_post_types)) {
        return $tabs;
    }

    // allowed post types
    if ($type == 'listings') {
        $listing_post_types = uwp_get_option('gd_profile_listings', array());
    } elseif ($type == 'reviews') {
        $listing_post_types = uwp_get_option('gd_profile_reviews', array());
    } elseif ($type == 'favorites') {
        $listing_post_types = uwp_get_option('gd_profile_favorites', array());
    } else {
        $listing_post_types = array();
    }

    if (!is_array($listing_post_types)) {
        $listing_post_types = array();
    }

    foreach ($listing_post_types as $post_type) {
        if (array_key_exists($post_type, $gd_post_types)) {
            $post_type_slug = $gd_post_types[$post_type]['has_archive'];

            if ($type == 'listings') {
                $count = uwp_post_count($user->ID, $post_type);
            } elseif ($type == 'reviews') {
                $count = uwp_geodir_get_reviews_by_user_id($post_type, $user->ID, true);
            } elseif ($type == 'favorites') {
                $count = uwp_geodir_count_favorite($post_type, $user->ID);
            } else {
                $count = 0;
            }

            if (empty($count)) {
                $count = 0;
            }
            $tabs[$post_type_slug] = array(
                'title' => $gd_post_types[$post_type]['labels']['name'],
                'count' => $count,
                'ptype' => $post_type
            );
        }
    }

    return apply_filters('uwp_profile_gd_tabs', $tabs, $user);
}

function uwp_profile_gd_subtabs_content($user, $type = 'listings')
{
    $subtab = get_query_var('uwp_subtab');
    $subtabs = uwp_profile_gd_subtabs($user, $type);
    $active_tab = !empty($subtab) && array_key_exists($subtab, $subtabs) ? $subtab : 'places';
    if (!empty($subtabs)) {
        $subtab_keys = array_keys($subtabs);
        $post_type = $subtabs[$subtab_keys[0]]['ptype'];
    } else {
        $post_type = false;
    }
    ?>
    <div class="uwp-profile-subcontent">
        <div class="uwp-profile-subnav">
            <?php if ($subtabs) { ?>
                <ul class="item-list-subtabs-ul">
                    <?php
                    foreach (uwp_profile_gd_subtabs($user, $type) as $tab_id => $tab) {

                        $tab_url = uwp_build_profile_tab_url($user->ID, $type, $tab_id);

                        $active = $active_tab == $tab_id ? ' active' : '';
                        $post_type = $active_tab == $tab_id ? $tab['ptype'] : $post_type;
                        ?>
                        <li id="uwp-profile-gd-<?php echo $tab_id; ?>" class="<?php echo $active; ?>">
                            <a href="<?php echo esc_url($tab_url); ?>">
                                <span class="uwp-profile-tab-label uwp-profile-gd-<?php echo $tab_id; ?>-label "><span
                                        class="uwp-profile-tab-sub-ul-count uwp-profile-sub-ul-gd-<?php echo $tab_id; ?>-count"><?php echo $tab['count']; ?></span> <?php echo esc_html($tab['title']); ?></span>
                            </a>
                        </li>
                        <?php
                    }
                    ?>
                </ul>
            <?php } ?>
        </div>

        <div class="uwp-profile-subtab-entries">
            <?php
            do_action('uwp_profile_gd_' . $type . '_subtab_content', $user, $post_type);
            ?>
        </div>
    </div>
<?php }


add_action('uwp_profile_gd_listings_subtab_content', 'wup_gd_get_listings', 10, 2);
function wup_gd_get_listings($user, $post_type)
{
    $gd_post_types = geodir_get_posttypes('array');
    ?>
    <h3><?php echo __($gd_post_types[$post_type]['labels']['name'], 'geodirectory') ?></h3>

    <div class="uwp-profile-item-block">
        <?php
        
        $paged = (get_query_var('paged')) ? absint(get_query_var('paged')) : 1;

        $args = array(
            'post_type' => $post_type,
            'post_status' => array('publish'),
            'posts_per_page' => uwp_get_option('profile_no_of_items', 10),
            'author' => $user->ID,
            'paged' => $paged,
        );

        if (get_current_user_id() == $user->ID) {
            $args['post_status'] = array('publish', 'draft', 'private');
        }
        // The Query
        $the_query = new WP_Query($args);

        // The Loop
        if ($the_query->have_posts()) {
            echo '<ul class="uwp-profile-item-ul">';
            while ($the_query->have_posts()) {
                $the_query->the_post();
                $post_id = get_the_ID();
                global $post;
                $post = geodir_get_post_info($post_id);
                setup_postdata($post);
                $post_avgratings = geodir_get_post_rating($post->ID);
                $post_ratings = geodir_get_rating_stars($post_avgratings, $post->ID);
                ob_start();
                geodir_comments_number($post->rating_count);
                $n_comments = ob_get_contents();
                ob_end_clean();
                ?>
                <li class="uwp-profile-item-li uwp-profile-item-clearfix">
                    <a class="uwp-profile-item-img" href="<?php echo get_the_permalink(); ?>">
                        <?php
                        if (has_post_thumbnail()) {
                            $thumb_url = get_the_post_thumbnail_url(get_the_ID(), array(80, 80));
                        } else {
                            $thumb_url = $thumb_url = plugins_url() . "/userswp/public/assets/images/no_thumb.png";
                        }
                        ?>
                        <img class="uwp-profile-item-alignleft uwp-profile-item-thumb" src="<?php echo $thumb_url; ?>">
                    </a>

                    <h3 class="uwp-profile-item-title">
                        <a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a>
                    </h3>
                    <div class="uwp-time-ratings-wrap">
                        <time class="uwp-profile-item-time published" datetime="<?php echo get_the_time('c'); ?>">
                            <?php echo get_the_date(); ?>
                        </time>
                        <?php echo '<div class="uwp-ratings">' . $post_ratings . ' <a href="' . get_comments_link() . '" class="uwp-num-comments">' . $n_comments . '</a></div>'; ?>
                        <?php
                        if (!is_user_logged_in()) {
                            do_action( 'geodir_after_favorite_html', $post->ID, 'listing' );
                        }
                        ?>
                    </div>
                    <div class="uwp-item-actions">
                        <?php
                        if (is_user_logged_in()) {
                            do_action( 'geodir_after_favorite_html', $post->ID, 'listing' );
                        }
                        if ($post->post_author == get_current_user_id()) {
                            $addplacelink = get_permalink(geodir_add_listing_page_id());
                            $editlink = geodir_getlink($addplacelink, array('pid' => $post->ID), false);

                            $ajaxlink = geodir_get_ajax_url();
                            $deletelink = geodir_getlink($ajaxlink, array('geodir_ajax' => 'add_listing', 'ajax_action' => 'delete', 'pid' => $post->ID), false);
                            ?>

                            <span class="geodir-authorlink clearfix">

                                <?php do_action('geodir_before_edit_post_link_on_listing'); ?>

                                <a href="<?php echo esc_url($editlink); ?>" class="geodir-edit"
                                   title="<?php _e('Edit Listing', 'geodirectory'); ?>">
                                        <?php
                                        $geodir_listing_edit_icon = apply_filters('geodir_listing_edit_icon', 'fa fa-edit');
                                        echo '<i class="' . $geodir_listing_edit_icon . '"></i>';
                                        ?>
                                        <?php _e('Edit', 'geodirectory'); ?>
                                    </a>
                                    <a href="<?php echo esc_url($deletelink); ?>" class="geodir-delete"
                                       title="<?php _e('Delete Listing', 'geodirectory'); ?>">
                                        <?php
                                        $geodir_listing_delete_icon = apply_filters('geodir_listing_delete_icon', 'fa fa-close');
                                        echo '<i class="' . $geodir_listing_delete_icon . '"></i>';
                                        ?>
                                        <?php _e('Delete', 'geodirectory'); ?>
                                    </a>

                                <?php do_action('geodir_after_edit_post_link_on_listing'); ?>

                            </span>

                        <?php } ?>
                    </div>
                    <div class="uwp-profile-item-summary">
                        <?php
                        $excerpt = strip_shortcodes(wp_trim_words(get_the_excerpt(), 15, '...'));
                        echo $excerpt;
                        if ($excerpt) {
                            ?>
                            <a href="<?php echo get_the_permalink(); ?>" class="more-link">Read More »</a>
                            <?php
                        }
                        ?>
                    </div>
                </li>
                <?php
            }
            echo '</ul>';
            /* Restore original Post Data */
            wp_reset_postdata();
        } else {
            echo "No " . $gd_post_types[$post_type]['labels']['name'] . " found";
        }
        do_action('uwp_profile_pagination', $the_query->max_num_pages);
        ?>
    </div>
    <?php
}

add_action('uwp_profile_gd_reviews_subtab_content', 'wup_gd_get_reviews', 10, 2);
function wup_gd_get_reviews($user, $post_type)
{
    $gd_post_types = geodir_get_posttypes('array');
    ?>
    <h3><?php echo __($gd_post_types[$post_type]['labels']['name'], 'geodirectory') ?></h3>

    <div class="uwp-profile-item-block">
        <?php
        $paged = (get_query_var('paged')) ? absint(get_query_var('paged')) : 1;
        $limit = uwp_get_option('profile_no_of_items', 10);
        $offset = ($paged - 1) * $limit;

        $total_reviews = uwp_geodir_get_reviews_by_user_id($post_type, $user->ID, true, $offset, $limit);
        $maximum_pages = ceil($total_reviews / $limit);

        $reviews = uwp_geodir_get_reviews_by_user_id($post_type, $user->ID, false, $offset, $limit);

        // The Loop
        if ($reviews) {
            echo '<ul class="uwp-profile-item-ul">';
            foreach ($reviews as $review) {
                $rating = 0;
                if (!empty($review))
                    $rating = geodir_get_commentoverall($review->comment_id);

                ?>
                <li class="uwp-profile-item-li uwp-profile-item-clearfix">
                    <a class="uwp-profile-item-img" href="<?php echo get_comment_link($review->comment_id); ?>">
                        <?php
                        $args = array(
                            'size' => 80
                        );
                        $thumb_url = get_avatar_url($review->user_id, $args);
                        ?>
                        <img class="uwp-profile-item-alignleft uwp-profile-item-thumb" src="<?php echo $thumb_url; ?>"/>
                    </a>

                    <h3 class="uwp-profile-item-title">
                        <a href="<?php echo get_comment_link($review->comment_id); ?>"><?php echo get_the_title($review->post_id); ?></a>
                    </h3>
                    <div class="uwp-time-ratings-wrap">
                        <time class="uwp-profile-item-time published" datetime="<?php echo get_the_time('c'); ?>">
                            <?php echo date_i18n(get_option('date_format'), strtotime(get_comment_date("", $review->comment_id))); ?>
                        </time>
                        <?php echo '<div class="uwp-ratings">' . geodir_get_rating_stars($rating, $review->comment_id) . '</div>'; ?>
                    </div>
                    <div class="uwp-profile-item-summary">
                        <?php
                        $excerpt = strip_shortcodes(wp_trim_words($review->comment_content, 15, '...'));
                        echo $excerpt;
                        if ($excerpt) {
                            ?>
                            <a href="<?php echo get_comment_link($review->comment_id); ?>" class="more-link">Read More
                                »</a>
                            <?php
                        }
                        ?>
                    </div>
                </li>
                <?php
            }
            echo '</ul>';
            /* Restore original Post Data */
            wp_reset_postdata();
        } else {
            echo "No " . $gd_post_types[$post_type]['labels']['name'] . " found";
        }

        do_action('uwp_profile_pagination', $maximum_pages);
        ?>
    </div>
    <?php
}

add_action('uwp_profile_gd_favorites_subtab_content', 'wup_gd_get_favorites', 10, 2);
function wup_gd_get_favorites($user, $post_type)
{
    $gd_post_types = geodir_get_posttypes('array');
    ?>
    <h3><?php echo __($gd_post_types[$post_type]['labels']['name'], 'geodirectory') ?></h3>

    <div class="uwp-profile-item-block">
        <?php
        $paged = (get_query_var('paged')) ? absint(get_query_var('paged')) : 1;

        $user_fav_posts = get_user_meta($user->ID, 'gd_user_favourite_post', true);

        if ($user_fav_posts) {
            $args = array(
                'post_type' => $post_type,
                'post_status' => array('publish'),
                'posts_per_page' => uwp_get_option('profile_no_of_items', 10),
                'post__in' => $user_fav_posts,
                'paged' => $paged,
            );

            if (get_current_user_id() == $user->ID) {
                $args['post_status'] = array('publish', 'draft', 'private');
            }

            // The Query
            $the_query = new WP_Query($args);

            // The Loop
            if ($the_query->have_posts()) {
                echo '<ul class="uwp-profile-item-ul">';
                while ($the_query->have_posts()) {
                    $the_query->the_post();
                    $post_id = get_the_ID();
                    global $post;
                    $post = geodir_get_post_info($post_id);
                    setup_postdata($post);
                    $post_avgratings = geodir_get_post_rating($post->ID);
                    $post_ratings = geodir_get_rating_stars($post_avgratings, $post->ID);
                    ob_start();
                    geodir_comments_number($post->rating_count);
                    $n_comments = ob_get_contents();
                    ob_end_clean();
                    ?>
                    <li class="uwp-profile-item-li uwp-profile-item-clearfix">
                        <a class="uwp-profile-item-img" href="<?php echo get_the_permalink(); ?>">
                            <?php
                            if (has_post_thumbnail()) {
                                $thumb_url = get_the_post_thumbnail_url(get_the_ID(), array(80, 80));
                            } else {
                                $thumb_url = $thumb_url = plugins_url() . "/userswp/public/assets/images/no_thumb.png";
                            }
                            ?>
                            <img class="uwp-profile-item-alignleft uwp-profile-item-thumb" src="<?php echo $thumb_url; ?>">
                        </a>

                        <h3 class="uwp-profile-item-title">
                            <a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a>
                        </h3>
                        <div class="uwp-time-ratings-wrap">
                            <time class="uwp-profile-item-time published" datetime="<?php echo get_the_time('c'); ?>">
                                <?php echo get_the_date(); ?>
                            </time>
                            <?php echo '<div class="uwp-ratings">' . $post_ratings . ' <a href="' . get_comments_link() . '" class="uwp-num-comments">' . $n_comments . '</a></div>'; ?>
                            <?php
                            if (!is_user_logged_in()) {
                                do_action( 'geodir_after_favorite_html', $post->ID, 'listing' );
                            }
                            ?>
                        </div>
                        <div class="uwp-item-actions">
                            <?php
                            if (is_user_logged_in()) {
                                do_action( 'geodir_after_favorite_html', $post->ID, 'listing' );
                            }
                            if ($post->post_author == get_current_user_id()) {
                                $addplacelink = get_permalink(geodir_add_listing_page_id());
                                $editlink = geodir_getlink($addplacelink, array('pid' => $post->ID), false);

                                $ajaxlink = geodir_get_ajax_url();
                                $deletelink = geodir_getlink($ajaxlink, array('geodir_ajax' => 'add_listing', 'ajax_action' => 'delete', 'pid' => $post->ID), false);
                                ?>

                                <span class="geodir-authorlink clearfix">

                                <?php do_action('geodir_before_edit_post_link_on_listing'); ?>

                                    <a href="<?php echo esc_url($editlink); ?>" class="geodir-edit"
                                       title="<?php _e('Edit Listing', 'geodirectory'); ?>">
                                        <?php
                                        $geodir_listing_edit_icon = apply_filters('geodir_listing_edit_icon', 'fa fa-edit');
                                        echo '<i class="' . $geodir_listing_edit_icon . '"></i>';
                                        ?>
                                        <?php _e('Edit', 'geodirectory'); ?>
                                    </a>
                                    <a href="<?php echo esc_url($deletelink); ?>" class="geodir-delete"
                                       title="<?php _e('Delete Listing', 'geodirectory'); ?>">
                                        <?php
                                        $geodir_listing_delete_icon = apply_filters('geodir_listing_delete_icon', 'fa fa-close');
                                        echo '<i class="' . $geodir_listing_delete_icon . '"></i>';
                                        ?>
                                        <?php _e('Delete', 'geodirectory'); ?>
                                    </a>

                                    <?php do_action('geodir_after_edit_post_link_on_listing'); ?>

                            </span>

                            <?php } ?>
                        </div>
                        <div class="uwp-profile-item-summary">
                            <?php
                            $excerpt = strip_shortcodes(wp_trim_words(get_the_excerpt(), 15, '...'));
                            echo $excerpt;
                            if ($excerpt) {
                                ?>
                                <a href="<?php echo get_the_permalink(); ?>" class="more-link">Read More »</a>
                                <?php
                            }
                            ?>
                        </div>
                    </li>
                    <?php
                }
                echo '</ul>';
                /* Restore original Post Data */
                wp_reset_postdata();
            } else {
                echo "No " . $gd_post_types[$post_type]['labels']['name'] . " found";
            }

            do_action('uwp_profile_pagination', $the_query->max_num_pages);
        }
        ?>
    </div>
    <?php
}

add_filter('geodir_login_url', 'uwp_get_gd_login_url');
function uwp_get_gd_login_url($url)
{
    $login_page_id = uwp_get_option('login_page', false);
    if ($login_page_id) {
        $uwp_url = get_permalink($login_page_id);

        if (strpos($url, 'redirect_add_listing') !== false) {
            $parsed = wp_parse_url($url);
            parse_str($parsed['query'], $query);
            $uwp_url = add_query_arg( array(
                        'redirect_to' => $query['redirect_add_listing'],
                    ), $uwp_url );
        }

        $url = $uwp_url;
    }
    return $url;
}

add_action('wp', 'geodir_uwp_author_redirect');
function geodir_uwp_author_redirect()
{
    $gd_dashboard = isset($_REQUEST['geodir_dashbord']) ? true : false;
    $favourite = isset($_REQUEST['list']) && $_REQUEST['list'] == 'favourite' ? true : false;
    $post_type = isset($_REQUEST['stype']) ? $_REQUEST['stype'] : NULL;

    // gd dashboard page
    if ($gd_dashboard && uwp_get_option('geodir_uwp_link_listing', '0')) {
        $author = get_query_var('author_name') ? get_user_by('slug', get_query_var('author_name')) : get_userdata(get_query_var('author'));

        if ($favourite && !uwp_get_option('geodir_uwp_link_favorite', '0')) {
            return;
        }

        if (!empty($author) && isset($author->ID) && $author_id = $author->ID) {
            if ($author_id) {
                $author_link = uwp_build_profile_tab_url($author_id);
                if ($post_type != '') {
                    $gd_post_types = geodir_get_posttypes('array');
                    $listing_post_types = uwp_get_option('gd_profile_listings', array());

                    if (!empty($gd_post_types) && array_key_exists($post_type, $gd_post_types) && !empty($listing_post_types) && in_array($post_type, $listing_post_types)) {
                        if ($favourite) {
                            $parent_slug = 'favorites';
                        } else {
                            $parent_slug = 'listings';
                        }

                        $post_type_slug = $gd_post_types[$post_type]['has_archive'];

                        $author_link = uwp_build_profile_tab_url($author_id, $parent_slug, $post_type_slug);
                    }
                }

                wp_redirect($author_link);
                exit;
            }
        }
    }
    return;
}

function uwp_gd_is_listings_tab() {
    global $wp_query;
    if (is_page() && class_exists('Users_WP')) {
        $profile_page = uwp_get_option('profile_page', false);
        if ($profile_page) {
            if (isset($wp_query->query_vars['uwp_profile'])
                && isset($wp_query->query_vars['uwp_tab'])
                && ($wp_query->query_vars['uwp_tab'] == 'listings' || $wp_query->query_vars['uwp_tab'] == 'favorites')
            ) {

                return true;

            }
        }
    }
    return false;
}


add_filter('geodir_post_status_is_author_page', 'uwp_geodir_post_status_is_author_page');
function uwp_geodir_post_status_is_author_page($value) {
    return $value || uwp_gd_is_listings_tab();
}

//add_action('geodir_after_edit_post_link_on_listing', 'uwp_geodir_add_post_status_author_page', 11);
function uwp_geodir_add_post_status_author_page()
{
    global $wpdb, $post;

    $html = '';
    if (get_current_user_id()) {
        if (uwp_gd_is_listings_tab() && !empty($post) && isset($post->post_author) && $post->post_author == get_current_user_id()) {

            // we need to query real status direct as we dynamically change the status for author on author page so even non author status can view them.
            $real_status = $wpdb->get_var("SELECT post_status from $wpdb->posts WHERE ID=$post->ID");
            $status = "<strong>(";
            $status_icon = '<i class="fa fa-play"></i>';
            if ($real_status == 'publish') {
                $status .= __('Published', 'geodirectory');
            } else {
                $status .= __('Not published', 'geodirectory');
                $status_icon = '<i class="fa fa-pause"></i>';
            }
            $status .= ")</strong>";

            $html = '<span class="geodir-post-status">' . $status_icon . ' <font class="geodir-status-label">' . __('Status: ', 'geodirectory') . '</font>' . $status . '</span>';
        }
    }

    if ($html != '') {
        echo apply_filters('geodir_filter_status_text_on_author_page', $html);
    }


}

function uwp_profile_gd_invoices_content($user) {
    if (!is_user_logged_in()) {
        return;
    }

    if (get_current_user_id() != $user->ID) {
        return;
    }
    ?>
    <h3><?php echo __('Invoices', 'uwp-gd'); ?></h3>

    <div class="uwp-profile-item-block">
        <?php
        $paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;

        $args = array(
            'post_type' => 'wpi_invoice',
            'post_status' => 'publish',
            'posts_per_page' => uwp_get_option('profile_no_of_items', 10),
            'author' => $user->ID,
            'paged' => $paged,
        );
        // The Query
        $the_query = new WP_Query($args);

        // The Loop
        if ($the_query->have_posts()) {
            echo '<ul class="uwp-profile-item-ul">';
            while ($the_query->have_posts()) {
                $the_query->the_post();
                $wpi_invoice = new WPInv_Invoice( get_the_ID() );
                ?>
                <li class="uwp-profile-item-li uwp-profile-item-clearfix">
                    <a class="uwp-profile-item-img" href="<?php echo get_the_permalink(); ?>">
                        <?php
                        if ( has_post_thumbnail() ) {
                            $thumb_url = get_the_post_thumbnail_url(get_the_ID(), array(80, 80));
                        } else {
                            $thumb_url = plugins_url()."/userswp/public/assets/images/no_thumb.png";
                        }
                        ?>
                        <img class="uwp-profile-item-alignleft uwp-profile-item-thumb" src="<?php echo $thumb_url; ?>">
                    </a>

                    <h3 class="uwp-profile-item-title">
                        <a href="<?php echo get_the_permalink(); ?>">Invoice <?php echo get_the_title(); ?></a>
                    </h3>
                    <time class="uwp-profile-item-time published" datetime="<?php echo get_the_time('c'); ?>">
                        <?php echo get_the_date(); ?>
                    </time>
                    <div class="uwp-profile-item-summary">
                        <div class="uwp-order-status">
                            <?php
                            echo __('Invoice Status: ', 'uwp-gd').$wpi_invoice->get_status( true ) . ( $wpi_invoice->is_recurring() && $wpi_invoice->is_parent() ? ' <span class="wpi-suffix">' . __( '(r)', 'invoicing' ) . '</span>' : '' );
                            ?>
                        </div>
                        <div class="uwp-order-total">
                            <?php
                            echo __('Invoice Total: ', 'uwp-gd'). $wpi_invoice->get_total( true );
                            ?>
                        </div
                    </div>
                </li>
                <?php
            }
            echo '</ul>';
            /* Restore original Post Data */
            wp_reset_postdata();
        } else {
            // no posts found
            echo "<p>".__('No Invoices Found', 'uwp-gd')."</p>";
        }
        do_action('uwp_profile_pagination', $the_query->max_num_pages);
        ?>
    </div>
    <?php
}