<?php
/*
Plugin Name: UsersWP - GeoDirectory
Plugin URI: https://wpgeodirectory.com
Description: GeoDirectory add-on for UsersWP.
Version: 1.0.0
Author: GeoDirectory team
Author URI: https://wpgeodirectory.com
License: GPL-2.0+
License URI: http://www.gnu.org/licenses/gpl-2.0.txt
Text Domain: uwp-gd
Domain Path: /languages
Requires at least: 3.1
Tested up to: 4.6
*/
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

class Users_WP_GeoDirectory {

    private static $instance;

    /**
     * Plugin Version
     */
    private $version = '1.0.0';

    private $file;

    private $plugin_dir;

    private $plugin_url;

    private $includes_dir;

    private $includes_url;

    /**
     * Plugin Title
     */
    public $title = 'UsersWP - GeoDirectory';


    public static function get_instance() {
        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Users_WP_GeoDirectory ) ) {
            self::$instance = new Users_WP_GeoDirectory;
            self::$instance->setup_globals();
            self::$instance->includes();
            self::$instance->setup_actions();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    private function __construct() {
        self::$instance = $this;
    }

    private function setup_globals() {

        // paths
        $this->file         = __FILE__;
        $this->basename     = apply_filters( 'uwp_gd_plugin_basenname', plugin_basename( $this->file ) );
        $this->plugin_dir   = apply_filters( 'uwp_gd_plugin_dir_path',  plugin_dir_path( $this->file ) );
        $this->plugin_url   = apply_filters( 'uwp_gd_plugin_dir_url',   plugin_dir_url ( $this->file ) );

        // includes
        $this->includes_dir = apply_filters( 'uwp_gd_includes_dir', trailingslashit( $this->plugin_dir . 'includes'  ) );
        $this->includes_url = apply_filters( 'uwp_gd_includes_url', trailingslashit( $this->plugin_url . 'includes'  ) );

    }

    private function setup_actions() {

        do_action( 'uwp_gd_setup_actions' );
    }

    public function load_textdomain() {

        // Set filter for plugin's languages directory
        $lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
        $lang_dir = apply_filters( 'uwp_gd_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale        = apply_filters( 'plugin_locale',  get_locale(), 'uwp-gd' );
        $mofile        = sprintf( '%1$s-%2$s.mo', 'uwp-gd', $locale );

        // Setup paths to current locale file
        $mofile_local  = $lang_dir . $mofile;
        $mofile_global = WP_LANG_DIR . '/uwp-geodirectory/' . $mofile;

        if ( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/uwp-gd/ folder
            load_textdomain( 'uwp-gd', $mofile_global );
        } elseif ( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/uwp-gd/languages/ folder
            load_textdomain( 'uwp-gd', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'uwp-gd', false, $lang_dir );
        }
    }

    private function includes() {

        $errors = uwp_gd_check_plugin_requirements();

        if ( empty ( $errors ) ) {
            require_once dirname(__FILE__) . '/includes/helpers.php';
            require_once dirname(__FILE__) . '/includes/gd-functions.php';

            do_action( 'uwp_gd_include_files' );

            if ( ! is_admin() )
                return;

            require_once dirname( __FILE__ ) . '/includes/admin-settings.php';
            do_action( 'uwp_gd_include_admin_files' );
        }

    }


}

function activate_uwp_geodirectory() {
    require_once('includes/class-uwp-gd-activator.php');
    UWP_GD_Activator::activate();
}
register_activation_hook( __FILE__, 'activate_uwp_geodirectory' );


function init_uwp_geodirectory() {

    $errors = uwp_gd_check_plugin_requirements();

    if ( empty ( $errors ) ) {
        Users_WP_GeoDirectory::get_instance();
    }

}
add_action( 'plugins_loaded', 'init_uwp_geodirectory', apply_filters( 'uwp_gd_action_priority', 10 ) );


// -------------------------
// Plugin requirement check
// -------------------------
function uwp_gd_check_plugin_requirements()
{
    $errors = array ();

    $name = get_file_data( __FILE__, array ( 'Plugin Name' ) );

    if ( ! class_exists( 'Users_WP' ) ) {
        $errors[] =  '<b>'.$name[0].'</b>'.__( ' addon requires <a href="https://wordpress.org/plugins/userswp/" target="_blank">UsersWP</a> plugin.', 'uwp-gd' );
    }

    if ( ! defined( 'GEODIRECTORY_VERSION' ) ) {
        $errors[] =  '<b>'.$name[0].'</b>'.__( ' addon requires <a href="https://wordpress.org/plugins/geodirectory/" target="_blank">GeoDirectory</a> plugin.', 'uwp-gd' );
    }

    return $errors;

}

add_action( 'admin_notices', 'uwp_gd_check_admin_notices', 0 );
function uwp_gd_check_admin_notices()
{
    $errors = uwp_gd_check_plugin_requirements();

    if ( empty ( $errors ) )
        return;

    // Suppress "Plugin activated" notice.
    unset( $_GET['activate'] );

    printf(
        '<div class="error"><p>%1$s</p>
        </div>',
        join( '</p><p>', $errors )
    );

}